@@ -212,332 +212,6 @@
 
 
 
-if (FALSE)
- AAaa.nohw <- function(link = "logit", ipA = NULL, iF = NULL) {
-
-
-
-
-
-  link <- as.list(substitute(link))
-  earg <- link2list(link)
-  link <- attr(earg, "function.name")
-
-
-  new("vglmff",
-  blurb = c("AA-Aa-aa phenotype (without Hardy-Weinberg assumption)\n\n",
-            "Links:    ",
-            namesof("pA", link, earg = earg), ", ", 
-            namesof("f",  "identitylink", tag = FALSE)),
-  deviance = Deviance.categorical.data.vgam,
-  initialize = eval(substitute(expression({
-    mustart.orig <- mustart
-
-    delete.zero.colns <- FALSE
-    eval(process.categorical.data.VGAM)
-
-    if (length(mustart.orig))
-      mustart <- mustart.orig
-
-    ok.col.ny <- c("AA","Aa","aa")
-    if (length(col.ny <- colnames(y)) == length(ok.col.ny) &&
-        setequal(ok.col.ny, col.ny)) {
-        if (!all(ok.col.ny == col.ny))
-          stop("the columns of the response matrix should have names ",
-               "(output of colnames()) ordered as c('AA','Aa','aa')")
-    }
-
-    predictors.names <-
-        c(namesof("pA", .link , earg = .earg , tag = FALSE),
-          namesof("f",  "identitylink", earg = list(), tag = FALSE))
-
-    if (is.null(etastart)) {
-      pA <- if (is.numeric( .ipA )) rep( .ipA , len = n) else
-            c(sqrt(mustart[, 1] - mustart[, 2] / 2))
-      f <- if (is.numeric( .iF )) rep( .iF , len = n) else
-           rep(0.01, len = n)  # 1- mustart[, 2]/(2*pA*(1-pA))
-      if (any(pA <= 0) || any(pA >= 1))
-        stop("bad initial value for 'pA'")
-      etastart <- cbind(theta2eta(pA, .link , earg = .earg ),
-                        theta2eta(f,  "identitylink"))
-      mustart <- NULL  # Since etastart has been computed.
-    }
-  }), list( .link = link, .ipA = ipA, .iF = iF, .earg = earg))),
-
-  linkinv = eval(substitute(function(eta, extra = NULL) {
-    pA <- eta2theta(eta[, 1], link = .link , earg = .earg )
-    f  <- eta2theta(eta[, 2], link = "identitylink", earg = list())
-    cbind(AA = pA^2+pA*(1-pA)*f,
-          Aa = 2*pA*(1-pA)*(1-f),
-          aa = (1-pA)^2 + pA*(1-pA)*f)
-  }, list( .link = link, .earg = earg))),
-
-  last = eval(substitute(expression({
-    misc$link <-    c(pA = .link , f = "identitylink")
-
-    misc$earg <- list(pA = .earg , f = list() )
-
-    misc$expected <- TRUE
-  }), list( .link = link, .earg = earg))),
-
-
-  loglikelihood = function(mu, y, w, residuals = FALSE, eta, extra = NULL)
-    if (residuals)
-      stop("loglikelihood residuals not implemented yet") else {
-      sum(dmultinomial(x = w * y, size = w, prob = mu,
-                       log = TRUE, dochecking = FALSE))
-    },
-  vfamily = c("AAaa.nohw", "vgenetic"),
-  deriv = eval(substitute(expression({
-    pA <- eta2theta(eta[, 1], link = .link , earg = .earg )
-    f  <- eta2theta(eta[, 2], link = "identitylink")
-    dP1 <- cbind(f + 2*pA*(1-f),
-                 2*(1-f)*(1-2*pA),
-                 -2*(1-pA) +f*(1-2*pA))
-    dP2 <- cbind(pA*(1-pA),
-                 -2*pA*(1-pA),
-                 pA*(1-pA))
-    dl1 <- rowSums(y * dP1 / mu)
-    dl2 <- rowSums(y * dP2 / mu)
-
-    dPP.deta <- dtheta.deta(pA, link = .link , earg = .earg )
-
-    c(w) * cbind(dPP.deta * dl1,
-                 dl2)
-  }), list( .link = link, .earg = earg))),
-  weight = eval(substitute(expression({
-    dPP <- array(c(dP1, dP2), c(n, 3, 2))
-    dPP.deta <- cbind(dtheta.deta(pA, link = .link , earg = .earg ),
-                      dtheta.deta(f,  link = "identitylink"))
-    wz <- matrix(as.numeric(NA), n, dimm(M))  # dimm(M)==3 because M==2
-    for (i1 in 1:M)
-      for (i2 in i1:M) {
-        index <- iam(i1, i2, M)
-        wz[,index] <- rowSums(dPP[,,i1,drop = TRUE] *
-                              dPP[,,i2,drop = TRUE] / mu) *
-                              dPP.deta[, i1] * dPP.deta[, i2]
-      }
-    c(w) * wz
-  }), list( .link = link, .earg = earg))))
-}
-
-
-
-
-
- if (FALSE)
- AB.Ab.aB.ab2 <- function(link = "logit", init.p = NULL) {
-
-
-
-
-
-  link <- as.list(substitute(link))
-  earg <- link2list(link)
-  link <- attr(earg, "function.name")
-
-
-  new("vglmff",
-  blurb = c("AB-Ab-aB-ab2 phenotype\n\n",
-            "Links:    ",
-            namesof("p", link, earg = earg)),
-  deviance = Deviance.categorical.data.vgam,
-  initialize = eval(substitute(expression({
-    mustart.orig <- mustart
-
-    delete.zero.colns <- FALSE
-    eval(process.categorical.data.VGAM)
-    predictors.names <- namesof("p", .link , earg = .earg , tag = FALSE)
-
-    if (length(mustart.orig)) {
-      mustart <- mustart.orig
-    }
-
-    ok.col.ny <- c("AB","Ab","aB","ab")
-    if (length(col.ny <- colnames(y)) == length(ok.col.ny) &&
-           setequal(ok.col.ny, col.ny)) {
-            if (!all(ok.col.ny == col.ny))
-                stop("the columns of the response matrix should have names ",
-                     "(output of colnames()) ordered as c('AB','Ab','aB','ab')")
-    }
-
-    mustart <- (mustart + y) / 2
-
-    if (is.null(etastart)) {
-      p.init <- if (is.numeric( .init.p )) rep( .init.p , n) else
-                rep(c(1 - 2 * sqrt(weighted.mean(mustart[, 4], w))), n)
-      p.init <- ifelse(p.init < 0.01, 0.01, p.init)
-      p.init <- ifelse(p.init > 0.99, 0.99, p.init)
-      etastart <- theta2eta(p.init, .link , earg = .earg )
-      mustart <- NULL  # Since etastart has been computed.
-    }
-    }), list( .link = link, .init.p=init.p, .earg = earg))),
-    linkinv = eval(substitute(function(eta,extra = NULL) {
-        p <- eta2theta(eta, link = .link , earg = .earg )
-        cbind("AB" = (2+(1-p)^2),
-              "Ab" = (1-(1-p)^2),
-              "aB" = (1-(1-p)^2),
-              "ab" = (1-p)^2) / 4
-    }, list( .link = link, .earg = earg) )),
-
-  last = eval(substitute(expression({
-    misc$link <-    c(p = .link )
-
-    misc$earg <- list(p = .earg )
-
-    misc$expected <- TRUE
-  }), list( .link = link, .earg = earg) )),
-
-
-  loglikelihood = function(mu, y, w, residuals = FALSE, eta, extra = NULL)
-    if (residuals)
-      stop("loglikelihood residuals not implemented yet") else {
-      sum(dmultinomial(x = w * y, size = w, prob = mu,
-                       log = TRUE, dochecking = FALSE))
-    },
-  vfamily = c("AB.Ab.aB.ab2", "vgenetic"),
-  deriv = eval(substitute(expression({
-    pp <- eta2theta(eta, link = .link , earg = .earg )
-    dP1 <- cbind(-0.5*(1-pp),
-                  0.5*(1-pp),
-                  0.5*(1-pp),
-                 -0.5*(1-pp))
-    dl1 <- rowSums(y * dP1 / mu)
-    dPP.deta <- dtheta.deta(pp, link = .link , earg = .earg )
-    c(w) * dPP.deta * dl1
-  }), list( .link = link, .earg = earg) )),
-  weight = eval(substitute(expression({
-    wz <- rowSums(dP1 * dP1 / mu) * dPP.deta^2
-    c(w) * wz
-  }), list( .link = link, .earg = earg) )))
-}
-
-
-
-
-
-
-
-
-
- if (FALSE)
- A1A2A3.orig <- function(link = "logit", ip1 = NULL, ip2 = NULL) {
-  link <- as.list(substitute(link))
-  earg <- link2list(link)
-  link <- attr(earg, "function.name")
-
-
-
-
-  new("vglmff",
-  blurb = c("A1A2A3 Allele System ",
-            "(A1A1, A1A2, A2A2, A1A3, A2A3, A3A3)\n\n",
-            "Links:    ",
-            namesof("pA", link, earg = earg), ", ", 
-            namesof("pB", link, earg = earg, tag = FALSE)),
-  deviance = Deviance.categorical.data.vgam,
-  infos = eval(substitute(function(...) {
-    list(M1 = 2,
-         Q1 = 6,
-         multipleResponses = FALSE,
-         expected = TRUE,
-         link = c("pA" = .link , "pB" = .link ))
-  }, list( .link = link ))),
-
-  initialize = eval(substitute(expression({
-    mustart.orig <- mustart
-
-    delete.zero.colns <- FALSE
-    eval(process.categorical.data.VGAM)
-
-    if (length(mustart.orig))
-      mustart <- mustart.orig
-
-        ok.col.ny <- c("A1A1", "A1A2", "A2A2", "A1A3", "A2A3", "A3A3")
-        if (length(col.ny <- colnames(y)) == length(ok.col.ny) &&
-           setequal(ok.col.ny, col.ny)) {
-            if (!all(ok.col.ny == col.ny))
-                stop("the columns of the response matrix should have names ",
-                     "(output of colnames()) ordered as ",
-                     "c('A1A1', 'A1A2', 'A2A2', 'A1A3', 'A2A3', 'A3A3')")
-        }
-    
-     predictors.names <-
-          c(namesof("pA", .link , earg = .earg , tag = FALSE),
-            namesof("pB", .link , earg = .earg , tag = FALSE))
-    mustart <- (y + mustart) / 2
-
-
-    if (is.null(etastart)) {
-        p1 <- if (is.numeric(.ip1 )) rep( .ip1 , len = n) else
-               rep(c(sqrt( weighted.mean(mustart[, 1], w) )), len = n)
-        p2 <- if (is.numeric(.ip2 )) rep( .ip2 , len = n) else
-               rep(c(sqrt( weighted.mean(mustart[, 3], w) )), len = n)
-        etastart <- cbind(theta2eta(p1, .link , earg = .earg ),
-                          theta2eta(p2, .link , earg = .earg ))
-        mustart <- NULL  # Since etastart has been computed.
-    }
-  }), list( .link = link, .ip1 = ip1, .ip2 = ip2, .earg = earg))),
-  linkinv = eval(substitute(function(eta, extra = NULL) {
-    p1 <- eta2theta(eta[, 1], link = .link , earg = .earg )
-    p2 <- eta2theta(eta[, 2], link = .link , earg = .earg )
-    qq <- abs(1 - p1 - p2)
-    cbind(A1A1 = p1*p1,
-          A1A2 = 2*p1*p2,
-          A2A2 = p2*p2,
-          A1A3 = 2*p1*qq,
-          A2A3 = 2*p2*qq,
-          A3A3 = qq*qq)
-  }, list( .link = link, .earg = earg))),
-
-  last = eval(substitute(expression({
-    misc$link <-    c(p1 = .link , p2 = .link )
-
-    misc$earg <- list(p1 = .earg , p2 = .earg )
-
-    misc$expected <- TRUE
-  }), list( .link = link, .earg = earg))),
-
-
-  loglikelihood = function(mu, y, w, residuals = FALSE,
-                           eta, extra = NULL)
-    if (residuals)
-      stop("loglikelihood residuals not implemented yet") else {
-      sum(dmultinomial(x = w * y, size = w, prob = mu,
-                       log = TRUE, dochecking = FALSE))
-    },
-  vfamily = c("A1A2A3", "vgenetic"),
-  deriv = eval(substitute(expression({
-    p1 <- eta2theta(eta[, 1], link = .link , earg = .earg )
-    p2 <- eta2theta(eta[, 2], link = .link , earg = .earg )
-
-    dl.dp1 <- (2*y[, 1]+y[, 2]+y[, 4])/p1 -
-              (2*y[,6]+y[, 4]+y[,5])/(1-p1-p2)
-    dl.dp2 <- (2*y[, 3]+y[, 2]+y[,5])/p2 -
-              (2*y[,6]+y[, 4]+y[,5])/(1-p1-p2)
-
-    dp1.deta <- dtheta.deta(p1, link = .link , earg = .earg )
-    dp2.deta <- dtheta.deta(p2, link = .link , earg = .earg )
-
-    c(w) * cbind(dl.dp1 * dp1.deta,
-              dl.dp2 * dp2.deta)
-  }), list( .link = link, .earg = earg))),
-  weight = eval(substitute(expression({
-    qq <- 1-p1-p2
-    wz <- matrix(as.numeric(NA), n, dimm(M))  # dimm(M)==3 because M==2
-    ned2l.dp12  <-  2 * (1/p1 + 1/qq)
-    ned2l.dp22  <-  2 * (1/p2 + 1/qq)
-    ned2l.dp1dp2 <-  2 / qq
-    wz[, iam(1, 1, M)] <- ned2l.dp12 * dp1.deta^2
-    wz[, iam(2, 2, M)] <- ned2l.dp22 * dp2.deta^2
-    wz[, iam(1, 2, M)] <- ned2l.dp1dp2 * dp1.deta * dp2.deta
-    c(w) * wz
-  }), list( .link = link, .earg = earg))))
-}
-
-
-
-
  MNSs <- function(link = "logit",
                   imS = NULL, ims = NULL, inS = NULL) {
 
