@@ -379,8 +379,8 @@
     }
     for (ii in 1:M) {
       index500 <- !is.finite(tmp200[, ii]) |
-                   (abs(tmp200[, ii]) < .Machine$double.eps)
-      if (any(index500)) { # Diagonal 0's are bad
+                  (abs(tmp200[, ii]) < .Machine$double.eps)
+      if (any(index500)) {  # Diagonal 0s are bad
         tmp200[index500, ii] <- .Machine$double.eps
       }
     }
@@ -1539,327 +1539,6 @@ rinv.gaussian <- function(n, mu, lambda) {
 
 
 
-if (FALSE)
- matched.binomial <-
-  function(multiple.responses = NULL, link = "logit",
-           parallel = TRUE,
-           smallno = .Machine$double.eps^(3/4)) {
-  link <- as.list(substitute(link))
-  earg <- link2list(link)
-  link <- attr(earg, "function.name")
-
-
-  if (!is.Numeric(smallno, positive = TRUE,
-                  length.arg = 1) ||
-      smallno > 1e-4)
-    stop("bad input for 'smallno'")
-  if (is.logical(parallel) && !parallel)
-    stop("'parallel' must be TRUE")
-
-    temp <- terms(multiple.responses)
-    multiple.responses <- attr(temp,"term.labels")
-    if (length(multiple.responses) != 1)
-      stop("cannot obtain the matching variable")
-    if (!is.character(multiple.responses) ||
-        length(multiple.responses) != 1) {
-      stop("bad input for 'multiple.responses'")
-    }
-
-    new("vglmff",
-    blurb = c("Matched binomial model (intercepts fitted)\n\n", 
-              "Link:     ", namesof("mu[,j]", link, earg = earg)),
-    constraints = eval(substitute(expression({
-        constraints <- cm.VGAM(matrix(1, M, 1), x = x,
-                               bool = .parallel ,
-                               constraints = constraints,
-                               apply.int = TRUE)
-        constraints[[extra$multiple.responses]] <- diag(M)
-
-        specialCM <- list(a = vector("list", M-1))
-        for (ii in 1:(M-1)) {
-          specialCM[[1]][[ii]] <-
-            (constraints[[extra$multiple.responses]])[, 1+ii,drop = FALSE]
-        }
-        names(specialCM) = extra$multiple.responses
-    }), list( .parallel = parallel ))),
-    initialize = eval(substitute(expression({
-        if (!all(w == 1))
-            extra$orig.w = w
-
-        multiple.responses <- .multiple.responses
-
-        NCOL <- function (x) 
-            if (is.array(x) && length(dim(x)) > 1 ||
-            is.data.frame(x)) ncol(x) else as.integer(1)
-
-        if (NCOL(y) == 1) {
-            if (is.factor(y)) y <- y != levels(y)[1]
-            nvec <- rep(1, n)
-            if (!all(y >= 0 & y <= 1))
-                stop("response values must be in [0, 1]")
-            mustart <- (0.5 + w * y) / (1 + w)
-            no.successes <- w * y
-            if (any(abs(no.successes - round(no.successes)) > 0.001))
-                stop("Number of successes must be integer-valued")
-        } else if (NCOL(y) == 2) {
-            if (any(abs(y - round(y)) > 0.001))
-                stop("Count data must be integer-valued")
-            nvec <- y[, 1] + y[, 2]
-            y <- ifelse(nvec > 0, y[, 1] / nvec, 0)
-            w <- w * nvec
-            mustart <- (0.5 + nvec * y) / (1 + nvec)
-        } else 
-             stop("Response not of the right form")
-
-    temp1 <- attr(x, "assign")
-    if (colnames(x)[1] != "(Intercept)")
-      stop("x must have an intercept")
-    M <- CCC <- length(temp1[[multiple.responses]]) +
-                (colnames(x)[1] == "(Intercept)")
-    temp9 <- x[,temp1[[multiple.responses]],drop = FALSE]
-    temp9 <- temp9 * matrix(2:CCC, n, CCC-1, byrow = TRUE)
-    temp9 <- apply(temp9, 1, max)
-      temp9[temp9 == 0] <- 1
-      extra$NoMatchedSets <- CCC
-      extra$n <- n
-      extra$M <- M
-      extra$multiple.responses <- multiple.responses
-      extra$index9 <- temp9
-
-    predictors.names <-
-      namesof("mu", .link , earg = .earg , short = TRUE)
-    predictors.names <- rep(predictors.names, len = M)
-  }), list( .link = link, .earg = earg,
-            .multiple.responses = multiple.responses ))),
-  linkinv = eval(substitute(function(eta, extra = NULL) {
-    mu <- eta2theta(eta, link = .link , earg = .earg )
-    mu[cbind(1:extra$n, extra$index9)]
-  }, list( .link = link, .earg = earg  ))),
-  last = eval(substitute(expression({
-    misc$link <- rep( .link , length = M)
-    names(misc$link) <- if (M > 1) paste("mu(matched set ",
-        1:M, ")", sep = "") else "mu"
-
-    misc$earg <- vector("list", M)
-    names(misc$earg) <- names(misc$link)
-    for (ii in 1:M)
-      misc$earg[[ii]] <- .earg
-
-    misc$expected <- TRUE
-  }), list( .link = link, .earg = earg))),
-  linkfun = eval(substitute(function(mu, extra = NULL) {
-    temp <- theta2eta(mu, .link , earg = .earg )
-    matrix(temp, extra$n, extra$M)
-  }, list( .link = link, .earg = earg))),
-  loglikelihood =
-    function(mu, y, w, residuals = FALSE, eta, extra = NULL,
-             summation = TRUE) {
-    if (residuals) {
-      w * (y / mu - (1-y) / (1-mu))
-    } else {
-
-      ycounts <- if (is.numeric(extra$orig.w)) y * w / extra$orig.w else
-                 y * w # Convert proportions to counts
-      nvec <- if (is.numeric(extra$orig.w)) round(w / extra$orig.w) else
-              round(w)
-
-      smallno <- 1.0e6 * .Machine$double.eps
-      if (max(abs(ycounts - round(ycounts))) > smallno)
-          warning("converting 'ycounts' to integer in @loglikelihood")
-      ycounts <- round(ycounts)
-
-      ll.elts <-
-        (if (is.numeric(extra$orig.w)) extra$orig.w else 1) *
-         dbinom(x = ycounts, size = nvec, prob = mu, log = TRUE)
-      if (summation) {
-        sum(ll.elts)
-      } else {
-        ll.elts
-      }
-    }
-  },
-  vfamily = c("matched.binomial", "vcategorical"),
-  deriv = eval(substitute(expression({
-    answer <- if ( .link == "logit") {
-      w * (y - mu)
-    } else if ( .link == "cloglog") {
-      mu.use <- mu
-        smallno <- 100 * .Machine$double.eps
-        mu.use[mu.use < smallno] <- smallno
-        mu.use[mu.use > 1 - smallno] <- 1 - smallno
-        -w * (y - mu) * log1p(-mu.use) / mu.use
-      } else {
-        w * dtheta.deta(mu, link = .link , earg = .earg ) *
-        (y/mu - 1)/(1-mu)
-      }
-      result <- matrix(0, n, M)
-      result[cbind(1:n, extra$index9)] <- answer
-    result
-  }), list( .link = link, .earg = earg))),
-  weight = eval(substitute(expression({
-    tmp100 <- mu*(1-mu)
-    answer <- if ( .link == "logit") {
-      cbind(w * tmp100)
-    } else if ( .link == "cloglog") {
-      cbind(w * (1-mu.use) * (log1p(-mu.use))^2 / mu.use )
-    } else {
-      cbind(w * dtheta.deta(mu, link = .link ,
-                            earg = .earg )^2 / tmp100)
-    }
-
-    result <- matrix( .smallno, n, M)
-    result[cbind(1:n, extra$index9)] <- answer
-    result
-  }), list( .link = link, .earg = earg, .smallno = smallno ))))
-}
-
-
-
-
-mypool <- function(x, index) {
-  answer <- x
-  uindex <- unique(index)
-  for (ii in uindex) {
-    ind0 <- (index == ii)
-    answer[ind0] <- sum(x[ind0])
-  }
-  answer
-}
-
-
-
-
-
-
-
-
-
- if (FALSE)
- mbino <- function() {
-    link <- "logit"
-    earg <- list()
-    parallel <- TRUE
-
-  link <- as.list(substitute(link))
-  earg <- link2list(link)
-  link <- attr(earg, "function.name")
-
-
-    if (is.logical(parallel) && !parallel)
-        stop("'parallel' must be TRUE")
-
-
-    new("vglmff",
-    blurb = c("Matched binomial model (intercepts not fitted)\n\n", 
-              "Link:     ", namesof("mu[,j]", link, earg = earg)),
-    constraints = eval(substitute(expression({
-        constraints <- cm.VGAM(matrix(1, M, 1), x = x,
-                           bool = .parallel , 
-                           constraints = constraints,
-                               apply.int = FALSE)
-    }), list( .parallel = parallel ))),
-    initialize = eval(substitute(expression({
-        if (colnames(x)[1] == "(Intercept)")
-            stop("the model matrix must not have an intercept")
-
-        NCOL = function (x) 
-            if (is.array(x) && length(dim(x)) > 1 ||
-            is.data.frame(x)) ncol(x) else as.integer(1)
-
-        if (NCOL(y) == 1) {
-            if (is.factor(y)) y = y != levels(y)[1]
-            nvec = rep(1, n)
-            if (!all(y >= 0 & y <= 1))
-                stop("response values must be in [0, 1]")
-            mustart = (0.5 + w * y) / (1 + w)
-            no.successes = w * y
-            if (any(abs(no.successes - round(no.successes)) > 0.001))
-                stop("Number of successes must be integer-valued")
-        } else if (NCOL(y) == 2) {
-            if (any(abs(y - round(y)) > 0.001))
-                stop("Count data must be integer-valued")
-            nvec = y[, 1] + y[, 2]
-            y = ifelse(nvec > 0, y[, 1] / nvec, 0)
-            w = w * nvec
-            mustart = (0.5 + nvec * y) / (1 + nvec)
-        } else 
-             stop("Response not of the right form")
-
-        if (!length(etastart))
-          etastart <- theta2eta(mustart, link = "logit", earg = list())
-
-        temp1 = attr(x, "assign")
-        multiple.responses = extra$multiple.responses
-        if (length(multiple.responses) != n)
-          stop("input extra$multiple.responses doesn't look right")
-
-        if (any(y != 0 & y != 1))
-            stop("response vector must have 0 or 1 values only")
-        xrle = rle(multiple.responses)
-        if (length(unique(multiple.responses)) != length(xrel$length))
-          stop("extra$multiple.responses must take on contiguous values")
-
-        temp9 = factor(multiple.responses)
-        extra$NoMatchedSets = levels(temp9)
-        extra$n = n
-        extra$M = M
-        extra$rlex = xrle
-        extra$index9 = temp9
-        predictors.names <-
-          namesof("mu", .link , earg = .earg , short = TRUE)
-  }), list( .link = link, .earg = earg,
-            .multiple.responses = multiple.responses ))),
-  linkinv = eval(substitute(function(eta, extra = NULL) {
-      denominator <- exp(eta)
-      numerator <- mypool(denominator, extra$multiple.responses)
-      numerator / denominator
-  }, list( .link = link, .earg = earg  ))),
-  last = eval(substitute(expression({
-    misc$link <-     c(mu = .link )
-
-    misc$earg <-  list(mu = .earg )
-
-    misc$expected <- TRUE
-  }), list( .link = link, .earg = earg))),
-  loglikelihood =
-    function(mu, y, w, residuals = FALSE, eta, extra = NULL,
-             summation = TRUE) {
-    if (residuals) {
-      c(w) * (y/mu - (1-y)/(1-mu))
-    } else {
-      ll.elts <- c(w) * (y*log(mu) + (1-y)*log1p(-mu))
-      if (summation) {
-        sum(ll.elts)
-      } else {
-        ll.elts
-      }
-    }
-  },
-  vfamily = c("mbin", "vcategorical"),
-  deriv = eval(substitute(expression({
-    answer <-
-      if ( .link == "logit") {
-        w * (y - mu)
-      } else stop("can only handle the logit link")
-        answer
-  }), list( .link = link, .earg = earg))),
-  weight = eval(substitute(expression({
-    tmp100 <- mu*(1-mu)
-    answer <- if ( .link == "logit") {
-        cbind(w * tmp100)
-    } else stop("can only handle the logit link")
-
-    result <- matrix( .smallno, n, M)
-    result[cbind(1:n, extra$index9)] <- answer
-    result
-  }), list( .link = link, .earg = earg, .smallno = smallno ))))
-}
-
-
-
-
-
-
 
 
 
